"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReferenceArg = void 0;
const Lookup_1 = require("../Lookup");
const ContainerArg_1 = require("./ContainerArg");
const TypeRef_1 = require("../TypeRef");
const errors_1 = require("../errors");
function toTypeRef(type) {
    return TypeRef_1.TypeRef.is(type) ? type : new TypeRef_1.TypeRef(type);
}
class ReferenceArg extends ContainerArg_1.ContainerArg {
    constructor(type, lookup) {
        super();
        this.type = type;
        this.lookup = lookup;
        Object.freeze(this);
    }
    getArgument(container) {
        const definitions = this.findDefinitions(container);
        if (Array.isArray(definitions)) {
            return Promise.all(this.findMulti(container).map(d => container.get(d)));
        }
        return container.get(definitions);
    }
    getDependentServices(container) {
        return this.findDefinitions(container);
    }
    findDefinitions(container) {
        if (this.type === "one") {
            return this.findOne(container);
        }
        return this.findMulti(container);
    }
    findOne(container) {
        const definitions = this.lookup.find(container);
        if (Array.isArray(definitions)) {
            if (definitions.length === 0) {
                throw errors_1.ERRORS.NO_MATCHING_SERVICE.create(this.lookup);
            }
            if (definitions.length > 1) {
                const servicesNames = definitions.map(s => s.name.toString());
                throw errors_1.ERRORS.AMBIGUOUS_SERVICE.create(servicesNames, this.lookup);
            }
            return definitions[0];
        }
        return definitions;
    }
    findMulti(container) {
        return this.lookup.find(container);
    }
}
exports.ReferenceArg = ReferenceArg;
ReferenceArg.one = {
    name(name) {
        return new ReferenceArg("one", new Lookup_1.Lookup.ByServiceName(name));
    },
    predicate(predicate) {
        return new ReferenceArg("one", new Lookup_1.Lookup.ByPredicate(predicate));
    },
    annotation(predicate) {
        return new ReferenceArg("one", new Lookup_1.Lookup.ByAnnotation(predicate));
    },
    type(type) {
        return new ReferenceArg("one", new Lookup_1.Lookup.ByType(toTypeRef(type)));
    },
};
ReferenceArg.multi = {
    predicate(predicate) {
        return new ReferenceArg("multi", new Lookup_1.Lookup.ByPredicate(predicate));
    },
    annotation(predicate) {
        return new ReferenceArg("multi", new Lookup_1.Lookup.ByAnnotation(predicate));
    },
    type(type) {
        return new ReferenceArg("multi", new Lookup_1.Lookup.ByType(toTypeRef(type)));
    },
};
