"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertNoCircularDependencies = void 0;
const ContainerArg_1 = require("./args/ContainerArg");
const errors_1 = require("./errors");
function assertNoCircularDependencies(container, currentDefinition) {
    detectCircularDependencies(container, currentDefinition, [currentDefinition]);
}
exports.assertNoCircularDependencies = assertNoCircularDependencies;
function detectCircularDependencies(container, definition, previousDefinitions) {
    for (const arg of definition.args) {
        if (arg instanceof ContainerArg_1.ContainerArg) {
            const dependencies = arg.getDependentServices(container);
            if (!dependencies) {
                continue;
            }
            for (const dependency of Array.isArray(dependencies) ? dependencies : [dependencies]) {
                if (previousDefinitions.indexOf(dependency) !== -1) {
                    const names = previousDefinitions
                        .concat([dependency])
                        .map(d => d.name.toString());
                    throw errors_1.ERRORS.CIRCULAR_DEPENDENCY_DETECTED.create(names);
                }
                detectCircularDependencies(container, dependency, previousDefinitions.concat([dependency]));
            }
        }
    }
}
