"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AutowiredService = void 0;
const Service_1 = require("./Service");
const serviceMetadata_1 = require("../serviceMetadata");
const is = require("predicates");
const TypeRef_1 = require("../TypeRef");
const index_1 = require("../index");
const errors_1 = require("../errors");
// eslint-disable-next-line @typescript-eslint/naming-convention
function AutowiredService(name) {
    return (clazz) => {
        const paramTypes = Reflect.getMetadata("design:paramtypes", clazz);
        const metadata = (0, serviceMetadata_1.ensureMetadata)(clazz);
        if (is.array(paramTypes) && clazz.length > 0) {
            for (const [index, paramType] of paramTypes.entries()) {
                if (metadata.constructorArguments[index]) {
                    continue;
                }
                const ref = TypeRef_1.TypeRef.createFromType(paramType);
                if (ref === undefined) {
                    throw errors_1.ERRORS.AUTO_WIRING_FAILED.create(`constructor (of ${clazz.name}) argument nr: ${index}`);
                }
                metadata.constructorArguments[index] = index_1.ReferenceArg.one.type(ref);
            }
        }
        else if (clazz.length > 0) {
            throw errors_1.ERRORS.AUTO_WIRING_NO_METADATA.create();
        }
        (0, Service_1.Service)(name)(clazz);
    };
}
exports.AutowiredService = AutowiredService;
