"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Inject = void 0;
const ContainerArg_1 = require("../args/ContainerArg");
require("reflect-metadata");
const ReferenceArg_1 = require("../args/ReferenceArg");
const is = require("predicates");
const serviceMetadata_1 = require("../serviceMetadata");
const types_1 = require("../types");
const TypeRef_1 = require("../TypeRef");
const errors_1 = require("../errors");
const assertServiceNameOrContainerArg = is.assert(is.any(types_1.ServiceName.is, ContainerArg_1.ContainerArg.is, TypeRef_1.TypeRef.is, is.func, is.undefined), "@Inject argument must be a string that represents service name, symbol, function or instance of ContainerArg or TypeRef");
// eslint-disable-next-line @typescript-eslint/naming-convention
function Inject(ref) {
    assertServiceNameOrContainerArg(ref);
    return function (target, property, indexOrDescriptor) {
        const isParameterDecorator = typeof indexOrDescriptor === "number";
        let arg;
        if (ref === undefined) {
            if (isParameterDecorator) {
                throw new Error("Using @Inject decorator without ref for function arguments is prohibited");
            }
            const designType = Reflect.getMetadata("design:type", target, property);
            arg = createReferenceForType(designType, `property ${property.toString()}`);
        }
        else if (TypeRef_1.TypeRef.is(ref)) {
            arg = ReferenceArg_1.ReferenceArg.one.type(ref);
        }
        else if (types_1.ServiceName.is(ref)) {
            arg = ReferenceArg_1.ReferenceArg.one.name(ref);
        }
        else if (ContainerArg_1.ContainerArg.is(ref)) {
            arg = ref;
        }
        else {
            arg = createReferenceForType(ref, isParameterDecorator
                ? `constructor (of ${target.name}) argument nr: ${indexOrDescriptor}`
                : `property ${property.toString()}`);
        }
        if (isParameterDecorator) {
            (0, serviceMetadata_1.ensureMetadata)(target).constructorArguments[indexOrDescriptor] = arg;
        }
        else {
            (0, serviceMetadata_1.ensureMetadata)(target.constructor).propertiesInjectors.set(property, arg);
        }
    };
}
exports.Inject = Inject;
function createReferenceForType(func, ...args) {
    const type = TypeRef_1.TypeRef.createFromType(func);
    if (type === undefined) {
        throw errors_1.ERRORS.AUTO_WIRING_FAILED.create(args[0]);
    }
    return ReferenceArg_1.ReferenceArg.one.type(type);
}
