"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ERRORS = exports.errorsDomain = void 0;
const errors_1 = require("@pallad/errors");
const code = (0, errors_1.formatCodeFactory)("ADIC_%c");
exports.errorsDomain = new errors_1.Domain();
exports.ERRORS = exports.errorsDomain.addErrorsDescriptorsMap({
    SERVICE_NOT_FOUND: errors_1.ErrorDescriptor.useMessageFormatter(code(1), (name) => `Service "${name}" does not exist`),
    AMBIGUOUS_SERVICE: errors_1.ErrorDescriptor.useMessageFormatter(code(2), (serviceNameList, lookup) => `Multiple services found (${serviceNameList.join(", ")}) with following lookup: ${lookup}`),
    NO_MATCHING_SERVICE: errors_1.ErrorDescriptor.useMessageFormatter(code(3), (lookup) => `No matching service for following lookup: ${lookup}`),
    CIRCULAR_DEPENDENCY_DETECTED: errors_1.ErrorDescriptor.useMessageFormatter(code(4), (dependencyNameList) => `Circular dependency found: ${dependencyNameList.join(" -> ")}`),
    INCOMPLETE_DEFINITION: errors_1.ErrorDescriptor.useMessageFormatter(code(5), (definitionName) => `Missing factory for service definition "${definitionName}". Define it as constructor, factory or value`),
    INVALID_SERVICE_ARGUMENTS_LENGTH: errors_1.ErrorDescriptor.useMessageFormatter(code(7), (name, requiredArgumentsLength, providedArgumentsLength) => `Invalid service "${name}" definition. Required constructor arguments: ${requiredArgumentsLength}, provided: ${providedArgumentsLength}`),
    MISSING_INJECT_DECORATOR: errors_1.ErrorDescriptor.useMessageFormatter(code(8), (position) => `Missing @Inject decorator for argument at position "${position}". Every constructor argument needs to have @Inject decorator`),
    MISSING_CONFIG_VALUE: errors_1.ErrorDescriptor.useMessageFormatter(code(9), (path) => `Config at path "${path}" is not defined and default value is not provided`),
    ALREADY_DEFINED: errors_1.ErrorDescriptor.useMessageFormatter(code(10), (name) => `Service "${name}" already defined`),
    AUTO_WIRING_FAILED: errors_1.ErrorDescriptor.useMessageFormatter(code(11), (typeDescription) => `Inferred type for ${typeDescription} is an interface, union type or built-in object that is not supported`),
    AUTO_WIRING_NO_METADATA: errors_1.ErrorDescriptor.useDefaultMessage(code(12), 'Metadata are missing. Make sure you have compiled typescript project with "emitDecoratorMetadata" option enabled'),
    CONFIG_PROVIDER_NOT_ATTACHED: errors_1.ErrorDescriptor.useDefaultMessage(code(13), "Config provider not attached to container. You need to use config middleware first."),
    OWNER_CANNOT_BE_CHANGED: errors_1.ErrorDescriptor.useDefaultMessage(code(14), "Owner of definition cannot be changed. Make sure you are not using same definition in multiple containers"),
    DEFINITION_WITHOUT_CONTAINER: errors_1.ErrorDescriptor.useMessageFormatter(code(15), (name) => `Cannot create service "${name}" due to lack of assigned container`),
});
