"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadServices = void 0;
const is = require("predicates");
const glob_1 = require("glob");
const Service_1 = require("./decorators/Service");
function createExtensionsPredicate(extensions, defaultResult) {
    if (extensions.length === 0) {
        return () => defaultResult;
    }
    if (extensions.length === 1) {
        return createExtensionPredicate(extensions[0]);
    }
    return is.or(...extensions.map(createExtensionPredicate));
}
function createExtensionPredicate(ext) {
    return is.endsWith(`.${ext}`);
}
function loadServices(container, opts) {
    var _a, _b;
    Service_1.Service.useContainer(container);
    const extensions = (_a = opts === null || opts === void 0 ? void 0 : opts.extensions) !== null && _a !== void 0 ? _a : ["ts", "js", "tsx"];
    const excludedExtensions = (_b = opts === null || opts === void 0 ? void 0 : opts.excludedExtensions) !== null && _b !== void 0 ? _b : ["d.ts", "d.tsx"];
    const patterns = (opts === null || opts === void 0 ? void 0 : opts.patterns)
        ? is.arr(opts.patterns)
            ? opts.patterns
            : [opts.patterns]
        : ["**/*"];
    const isMatchingExtension = createExtensionsPredicate(extensions, true);
    const isExcludedExtension = createExtensionsPredicate(excludedExtensions, false);
    const isValidExtension = is.and(isMatchingExtension, is.not(isExcludedExtension));
    for (const pattern of patterns) {
        const modulesPaths = (0, glob_1.sync)(pattern, {
            cwd: opts === null || opts === void 0 ? void 0 : opts.currentDir,
            nodir: true,
            realpath: true,
            nosort: true,
        });
        for (const modulePath of modulesPaths) {
            if (isValidExtension(modulePath)) {
                require(modulePath);
            }
        }
    }
}
exports.loadServices = loadServices;
