"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfigProviderForContainer = exports.attachConfigProviderToContainer = exports.configMiddleware = void 0;
const is = require("predicates");
const types_1 = require("../types");
const errors_1 = require("../errors");
const assertConfigProvider = is.assert(is.func, "Invalid config provider - must be a function");
function configMiddleware(configProvider) {
    assertConfigProvider(configProvider);
    const f = (definition, next) => {
        return next(definition);
    };
    f[types_1.onMiddlewareAttach] = (container) => {
        attachConfigProviderToContainer(container, configProvider);
    };
    return f;
}
exports.configMiddleware = configMiddleware;
const configMap = new WeakMap();
function attachConfigProviderToContainer(container, configProvider) {
    if (!configMap.has(container)) {
        configMap.set(container, configProvider);
    }
}
exports.attachConfigProviderToContainer = attachConfigProviderToContainer;
function getConfigProviderForContainer(container) {
    if (!configMap.has(container)) {
        throw errors_1.ERRORS.CONFIG_PROVIDER_NOT_ATTACHED.create();
    }
    return configMap.get(container);
}
exports.getConfigProviderForContainer = getConfigProviderForContainer;
